==> Java-Swing-0.02.tar.gz: Java-Swing-0.02/java/PerlDocumentListener.java <==
import javax.swing.event.DocumentListener;
import org.perl.inline.java.*;

public class      PerlDocumentListener
       extends    InlineJavaPerlCaller
       implements DocumentListener
{
    String sender;
    String callbacks;

    public PerlDocumentListener(String sender, String callbacks)
        throws InlineJavaException
    {
        this.sender    = sender;
        this.callbacks = callbacks;
    }

    public void insertUpdate(javax.swing.event.DocumentEvent event)  {
        try {
            CallPerl(
                "Java::Swing::DocumentListener",
                "_DocumentListener",
                new Object[] {sender, callbacks, "insertUpdate", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void removeUpdate(javax.swing.event.DocumentEvent event)  {
        try {
            CallPerl(
                "Java::Swing::DocumentListener",
                "_DocumentListener",
                new Object[] {sender, callbacks, "removeUpdate", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void changedUpdate(javax.swing.event.DocumentEvent event)  {
        try {
            CallPerl(
                "Java::Swing::DocumentListener",
                "_DocumentListener",
                new Object[] {sender, callbacks, "changedUpdate", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
}

==> Java-Swing-0.13.tar.gz: Java-Swing-0.13/java/PerlDocumentListener.java <==
import javax.swing.event.DocumentListener;
import org.perl.inline.java.*;

public class      PerlDocumentListener
       extends    InlineJavaPerlCaller
       implements DocumentListener
{
    String sender;
    String callbacks;

    public PerlDocumentListener() throws InlineJavaException { }

    public PerlDocumentListener(String sender, String callbacks)
        throws InlineJavaException
    {
        this.sender    = sender;
        this.callbacks = callbacks;
    }

    public void setSender   (String sender)    { this.sender    = sender; }
    public void setCallbacks(String callbacks) { this.callbacks = callbacks; }

    public void insertUpdate(javax.swing.event.DocumentEvent event)  {
        try {
            CallPerl(
                "Java::Swing",
                "_Listener",
                new Object[] {sender, callbacks, "insertUpdate", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void removeUpdate(javax.swing.event.DocumentEvent event)  {
        try {
            CallPerl(
                "Java::Swing",
                "_Listener",
                new Object[] {sender, callbacks, "removeUpdate", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void changedUpdate(javax.swing.event.DocumentEvent event)  {
        try {
            CallPerl(
                "Java::Swing",
                "_Listener",
                new Object[] {sender, callbacks, "changedUpdate", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
}
